@@ -1,5 +1,5 @@
-# encoding: utf-8
-
+# This file is part of CycloneDX Python Library
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -13,7 +13,8 @@
 # limitations under the License.
 #
 # SPDX-License-Identifier: Apache-2.0
-#
+# Copyright (c) OWASP Foundation. All Rights Reserved.
+
 
 """
 Exceptions that are for specific error scenarios during the output of a Model to a SBOM.
@@ -22,9 +23,17 @@ Exceptions that are for specific error scenarios during the output of a Model to
 from . import CycloneDxException
 
 
-class ComponentVersionRequiredException(CycloneDxException):
+class BomGenerationErrorException(CycloneDxException):
     """
-    Exception raised when attempting to output to an SBOM version that mandates a Component has a version,
-    but one is not available/present.
+    Raised if there is an unknown error.
+    """
+    pass
+
+
+class FormatNotSupportedException(CycloneDxException):
+    """
+    Exception raised when attempting to output a BOM to a format not supported in the requested version.
+
+    For example, JSON is not supported prior to 1.2.
     """
     pass
