@@ -16,7 +16,8 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 import re
-from typing import TYPE_CHECKING, Any, Iterable, Optional, Union
+from collections.abc import Iterable
+from typing import TYPE_CHECKING, Any, Optional, Union
 
 import py_serializable as serializable
 from sortedcontainers import SortedSet
@@ -29,12 +30,12 @@ from . import ExternalReference, Property
 from .bom_ref import BomRef
 
 if TYPE_CHECKING:  # pragma: no cover
-    from typing import Type, TypeVar
+    from typing import TypeVar
 
     _T_CreId = TypeVar('_T_CreId', bound='CreId')
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class CreId(serializable.helpers.BaseHelper):
     """
     Helper class that allows us to perform validation on data strings that must conform to
@@ -65,7 +66,7 @@ class CreId(serializable.helpers.BaseHelper):
             f'Attempt to serialize a non-CreId: {o!r}')
 
     @classmethod
-    def deserialize(cls: 'Type[_T_CreId]', o: Any) -> '_T_CreId':
+    def deserialize(cls: 'type[_T_CreId]', o: Any) -> '_T_CreId':
         return cls(id=str(o))
 
     def __eq__(self, other: Any) -> bool:
@@ -88,10 +89,14 @@ class CreId(serializable.helpers.BaseHelper):
         return self._id
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Requirement:
     """
     A requirement comprising a standard.
+
+    .. note::
+        See the CycloneDX Schema for hashType:
+        https://cyclonedx.org/docs/1.7/json/#definitions_standards_items_requirements
     """
 
     def __init__(
@@ -110,11 +115,11 @@ class Requirement:
         self.identifier = identifier
         self.title = title
         self.text = text
-        self.descriptions = descriptions or ()  # type:ignore[assignment]
-        self.open_cre = open_cre or ()  # type:ignore[assignment]
-        self.parent = parent  # type:ignore[assignment]
-        self.properties = properties or ()  # type:ignore[assignment]
-        self.external_references = external_references or ()  # type:ignore[assignment]
+        self.descriptions = descriptions or ()
+        self.open_cre = open_cre or ()
+        self.parent = parent
+        self.properties = properties or ()
+        self.external_references = external_references or ()
 
     @property
     @serializable.type_mapping(BomRef)
@@ -281,10 +286,13 @@ class Requirement:
             f'title={self.title}, text={self.text}, parent={self.parent}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Level:
     """
     Level of compliance for a standard.
+
+    .. note::
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/json/#definitions_standards_items_levels
     """
 
     def __init__(
@@ -299,7 +307,7 @@ class Level:
         self.identifier = identifier
         self.title = title
         self.description = description
-        self.requirements = requirements or ()  # type:ignore[assignment]
+        self.requirements = requirements or ()
 
     @property
     @serializable.type_mapping(BomRef)
@@ -367,7 +375,7 @@ class Level:
 
     @requirements.setter
     def requirements(self, requirements: Iterable[Union[str, BomRef]]) -> None:
-        self._requirements = SortedSet(map(_bom_ref_from_str,  # type: ignore[arg-type]
+        self._requirements = SortedSet(map(_bom_ref_from_str,  # type:ignore[arg-type]
                                            requirements))
 
     def __comparable_tuple(self) -> _ComparableTuple:
@@ -396,11 +404,14 @@ class Level:
             f'title={self.title}, description={self.description}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Standard:
     """
     A standard of regulations, industry or organizational-specific standards, maturity models, best practices,
     or any other requirements.
+
+    .. note::
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_standard
     """
 
     def __init__(
@@ -420,9 +431,9 @@ class Standard:
         self.version = version
         self.description = description
         self.owner = owner
-        self.requirements = requirements or ()  # type:ignore[assignment]
-        self.levels = levels or ()  # type:ignore[assignment]
-        self.external_references = external_references or ()  # type:ignore[assignment]
+        self.requirements = requirements or ()
+        self.levels = levels or ()
+        self.external_references = external_references or ()
         # TODO: signature
 
     @property
@@ -573,17 +584,23 @@ class Standard:
             f'description={self.description}, owner={self.owner}>'
 
 
-@serializable.serializable_class(name='definitions')
+@serializable.serializable_class(
+    name='definitions',
+    ignore_unknown_during_deserialization=True
+)
 class Definitions:
     """
     The repository for definitions
+
+    .. note::
+        See the CycloneDX Schema for hashType: https://cyclonedx.org/docs/1.7/xml/#type_definitionsType
     """
 
     def __init__(
         self, *,
         standards: Optional[Iterable[Standard]] = None
     ) -> None:
-        self.standards = standards or ()  # type:ignore[assignment]
+        self.standards = standards or ()
 
     @property
     @serializable.xml_array(serializable.XmlArraySerializationType.NESTED, 'standard')
