@@ -15,8 +15,9 @@
 # SPDX-License-Identifier: Apache-2.0
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
+from collections.abc import Iterable
 from datetime import datetime
-from typing import Iterable, Optional
+from typing import Optional
 
 import py_serializable as serializable
 from sortedcontainers import SortedSet
@@ -26,13 +27,13 @@ from ..model import Note, Property, XsUri
 from ..model.issue import IssueType
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class ReleaseNotes:
     """
     This is our internal representation of a `releaseNotesType` for a Component in a BOM.
 
     .. note::
-        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.6/#type_releaseNotesType
+        See the CycloneDX Schema definition: https://cyclonedx.org/docs/1.7/xml/#type_releaseNotesType
     """
 
     def __init__(
@@ -54,11 +55,11 @@ class ReleaseNotes:
         self.social_image = social_image
         self.description = description
         self.timestamp = timestamp
-        self.aliases = aliases or []  # type:ignore[assignment]
-        self.tags = tags or []  # type:ignore[assignment]
-        self.resolves = resolves or []  # type:ignore[assignment]
-        self.notes = notes or []  # type:ignore[assignment]
-        self.properties = properties or []  # type:ignore[assignment]
+        self.aliases = aliases or []
+        self.tags = tags or []
+        self.resolves = resolves or []
+        self.notes = notes or []
+        self.properties = properties or []
 
     @property
     @serializable.xml_sequence(1)
@@ -249,6 +250,11 @@ class ReleaseNotes:
             return self.__comparable_tuple() == other.__comparable_tuple()
         return False
 
+    def __lt__(self, other: object) -> bool:
+        if isinstance(other, ReleaseNotes):
+            return self.__comparable_tuple() < other.__comparable_tuple()
+        return NotImplemented
+
     def __hash__(self) -> int:
         return hash(self.__comparable_tuple())
 
