@@ -28,14 +28,19 @@ Since CycloneDX schema version 1.4, this has become part of the core schema.
     See the CycloneDX Schema extension definition https://cyclonedx.org/docs/1.7/xml/#type_vulnerabilitiesType
 """
 
-
 import re
+import sys
 from collections.abc import Iterable
 from datetime import datetime
 from decimal import Decimal
 from enum import Enum
 from typing import Any, Optional, Union
 
+if sys.version_info >= (3, 13):
+    from warnings import deprecated
+else:
+    from typing_extensions import deprecated
+
 import py_serializable as serializable
 from sortedcontainers import SortedSet
 
@@ -724,38 +729,18 @@ class VulnerabilitySeverity(str, Enum):
     UNKNOWN = 'unknown'
 
     @staticmethod
+    @deprecated('Deprecated - use cyclonedx.contrib.vulnerability.cvss.vs_from_cvss_scores instead')
     def get_from_cvss_scores(scores: Union[tuple[float, ...], float, None]) -> 'VulnerabilitySeverity':
-        """
+        """Deprecated — Alias of :func:`cyclonedx.contrib.vulnerability.cvss.vs_from_cvss_scores()`.
+
         Derives the Severity of a Vulnerability from it's declared CVSS scores.
 
-        Args:
-            scores: A `tuple` of CVSS scores. CVSS scoring system allows for up to three separate scores.
-
-        Returns:
-            Always returns an instance of `VulnerabilitySeverity`.
+        .. deprecated:: next
+            Use ``cyclonedx.contrib.vulnerability.cvss.vs_from_cvss_scores()`` instead.
         """
-        if type(scores) is float:
-            scores = (scores,)
+        from ..contrib.vulnerability.cvss import vs_from_cvss_scores
 
-        if scores is None:
-            return VulnerabilitySeverity.UNKNOWN
-
-        max_cvss_score: float
-        if isinstance(scores, tuple):
-            max_cvss_score = max(scores)
-        else:
-            max_cvss_score = float(scores)
-
-        if max_cvss_score >= 9.0:
-            return VulnerabilitySeverity.CRITICAL
-        elif max_cvss_score >= 7.0:
-            return VulnerabilitySeverity.HIGH
-        elif max_cvss_score >= 4.0:
-            return VulnerabilitySeverity.MEDIUM
-        elif max_cvss_score > 0.0:
-            return VulnerabilitySeverity.LOW
-        else:
-            return VulnerabilitySeverity.NONE
+        return vs_from_cvss_scores(scores)
 
 
 @serializable.serializable_class(ignore_unknown_during_deserialization=True)
