@@ -17,10 +17,11 @@
 
 import base64
 import sys
+from collections.abc import Iterable
 from datetime import datetime, timezone
 from decimal import Decimal
 from inspect import getmembers, isfunction
-from typing import Any, List, Optional, Tuple
+from typing import Any, Optional
 from uuid import UUID
 
 # See https://github.com/package-url/packageurl-python/issues/65
@@ -41,12 +42,11 @@ from cyclonedx.model import (
     Property,
     XsUri,
 )
-from cyclonedx.model.bom import Bom, BomMetaData
+from cyclonedx.model.bom import Bom, BomMetaData, DistributionConstraints, TlpClassification
 from cyclonedx.model.bom_ref import BomRef
 from cyclonedx.model.component import (
     Commit,
     Component,
-    ComponentEvidence,
     ComponentScope,
     ComponentType,
     Diff,
@@ -57,6 +57,16 @@ from cyclonedx.model.component import (
     Swhid,
     Swid,
 )
+from cyclonedx.model.component_evidence import (
+    AnalysisTechnique,
+    CallStack,
+    CallStackFrame,
+    ComponentEvidence,
+    Identity,
+    IdentityField,
+    Method,
+    Occurrence,
+)
 from cyclonedx.model.contact import OrganizationalContact, OrganizationalEntity, PostalAddress
 from cyclonedx.model.crypto import (
     AlgorithmProperties,
@@ -455,6 +465,35 @@ def get_bom_with_component_setuptools_complete() -> Bom:
     return _make_bom(components=[get_component_setuptools_complete()])
 
 
+def get_bom_with_component_evidence() -> Bom:
+    bom = _make_bom()
+    tool_component = Component(
+        name='product-cbom-generator',
+        type=ComponentType.APPLICATION,
+        bom_ref='cbom:generator'
+    )
+    bom.metadata.tools.components.add(tool_component)
+    bom.metadata.component = Component(
+        name='root-component',
+        type=ComponentType.APPLICATION,
+        licenses=[DisjunctiveLicense(id='MIT')],
+        bom_ref='myApp',
+    )
+    component = Component(
+        name='setuptools', version='50.3.2',
+        bom_ref='pkg:pypi/setuptools@50.3.2?extension=tar.gz',
+        purl=PackageURL(
+            type='pypi', name='setuptools', version='50.3.2', qualifiers='extension=tar.gz'
+        ),
+        licenses=[DisjunctiveLicense(id='MIT')],
+        author='Test Author'
+    )
+    component.evidence = get_component_evidence_basic(tools=[tool_component])
+    bom.components.add(component)
+    bom.register_dependency(bom.metadata.component, depends_on=[component])
+    return bom
+
+
 def get_bom_with_component_setuptools_with_vulnerability() -> Bom:
     bom = _make_bom()
     component = get_component_setuptools_simple()
@@ -543,12 +582,13 @@ def get_bom_just_complete_metadata() -> Bom:
     )]
     bom.metadata.lifecycles = [PredefinedLifecycle(LifecyclePhase.BUILD)]
     bom.metadata.properties = get_properties_1()
+    bom.metadata.distribution_constraints = DistributionConstraints(tlp=TlpClassification.GREEN)
     return bom
 
 
 def get_bom_with_external_references() -> Bom:
     bom = _make_bom(external_references=[
-        get_external_reference_1(), get_external_reference_2()
+        get_external_reference_1(), get_external_reference_2(), get_external_reference_with_properties()
     ])
     return bom
 
@@ -737,6 +777,68 @@ def get_component_setuptools_complete(include_pedigree: bool = True) -> Componen
     return component
 
 
+def get_component_evidence_basic(tools: Iterable[Component]) -> ComponentEvidence:
+    """
+    Returns a basic ComponentEvidence object for testing.
+    """
+    return ComponentEvidence(
+        identity=[
+            Identity(
+                field=IdentityField.NAME,
+                confidence=Decimal('0.9'),
+                concluded_value='example-component',
+                methods=[
+                    Method(
+                        technique=AnalysisTechnique.SOURCE_CODE_ANALYSIS,
+                        confidence=Decimal('0.8'),
+                        value='analysis-tool'
+                    ),
+                ],
+                tools=(tool.bom_ref for tool in tools)
+            ),
+            Identity(
+                field=IdentityField.HASH,
+                confidence=Decimal('0.1'),
+                concluded_value='example-hash',
+                methods=[
+                    Method(
+                        technique=AnalysisTechnique.ATTESTATION,
+                        confidence=Decimal('0.1'),
+                        value='analysis-tool'
+                    ),
+                ],
+                tools=(tool.bom_ref for tool in tools)
+            ),
+        ],
+        occurrences=[
+            Occurrence(
+                location='path/to/file',
+                line=42,
+                offset=16,
+                symbol='exampleSymbol',
+                additional_context='Found in source code',
+            )
+        ],
+        callstack=CallStack(
+            frames=[
+                CallStackFrame(
+                    package='example.package',
+                    module='example.module',
+                    function='example_function',
+                    parameters=['param1', 'param2'],
+                    line=10,
+                    column=5,
+                    full_filename='path/to/file',
+                )
+            ]
+        ),
+        licenses=[DisjunctiveLicense(id='MIT')],
+        copyright=[
+            Copyright(text='Commercial'), Copyright(text='Commercial 2')
+        ]
+    )
+
+
 def get_component_setuptools_simple(
     bom_ref: Optional[str] = 'pkg:pypi/setuptools@50.3.2?extension=tar.gz'
 ) -> Component:
@@ -794,6 +896,17 @@ def get_external_reference_2() -> ExternalReference:
     )
 
 
+def get_external_reference_with_properties() -> ExternalReference:
+    return ExternalReference(
+        type=ExternalReferenceType.VCS,
+        url=XsUri('https://cyclonedx.org'),
+        properties=[
+            Property(name='property_1', value='value_1'),
+            Property(name='property_2', value='value_2')
+        ]
+    )
+
+
 def get_issue_1() -> IssueType:
     return IssueType(
         type=IssueClassification.SECURITY, id='CVE-2021-44228', name='Apache Log3Shell',
@@ -875,7 +988,7 @@ def get_pedigree_1() -> Pedigree:
     )
 
 
-def get_properties_1() -> List[Property]:
+def get_properties_1() -> list[Property]:
     return [
         Property(name='key1', value='val1'),
         Property(name='key2', value='val2')
@@ -992,7 +1105,7 @@ def get_bom_metadata_licenses_invalid() -> Bom:
     return Bom(metadata=BomMetaData(licenses=get_invalid_license_repository()))
 
 
-def get_invalid_license_repository() -> List[License]:
+def get_invalid_license_repository() -> list[License]:
     """
     license expression and a license -- this is an invalid constellation according to schema
     see https://github.com/CycloneDX/specification/pull/205
@@ -1261,7 +1374,7 @@ def get_bom_for_issue_598_multiple_components_with_purl_qualifiers() -> Bom:
     ])
 
 
-def bom_all_same_bomref() -> Tuple[Bom, int]:
+def bom_all_same_bomref() -> tuple[Bom, int]:
     bom = Bom()
     bom.metadata.component = Component(name='root', bom_ref='foo', components=[
         Component(name='root.sub', bom_ref='foo')])
@@ -1302,6 +1415,17 @@ def get_bom_with_lifecycles() -> Bom:
     )
 
 
+def get_bom_with_distribution_constraints() -> Bom:
+    return _make_bom(
+        metadata=BomMetaData(
+            distribution_constraints=DistributionConstraints(
+                tlp=TlpClassification.AMBER_AND_STRICT
+            ),
+            component=Component(name='app', type=ComponentType.APPLICATION, bom_ref='my-app'),
+        )
+    )
+
+
 def get_bom_with_definitions_standards() -> Bom:
     """
     Returns a BOM with definitions and standards only.
@@ -1483,6 +1607,7 @@ all_get_bom_funct_with_incomplete_deps = {
     get_bom_with_component_setuptools_with_v16_fields,
     get_bom_for_issue_630_empty_property,
     get_bom_with_lifecycles,
+    get_bom_with_distribution_constraints,
     get_bom_with_definitions_standards,
     get_bom_with_definitions_and_detailed_standards,
 }
