@@ -16,12 +16,10 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 import datetime
-from typing import List
 from unittest import TestCase
 
 from cyclonedx.model import (
     AttachedText,
-    Copyright,
     Encoding,
     ExternalReference,
     ExternalReferenceType,
@@ -29,16 +27,7 @@ from cyclonedx.model import (
     Property,
     XsUri,
 )
-from cyclonedx.model.component import (
-    Commit,
-    Component,
-    ComponentEvidence,
-    ComponentType,
-    Diff,
-    Patch,
-    PatchClassification,
-    Pedigree,
-)
+from cyclonedx.model.component import Commit, Component, ComponentType, Diff, Patch, PatchClassification, Pedigree
 from cyclonedx.model.issue import IssueClassification, IssueType
 from tests import reorder
 from tests._data.models import (
@@ -143,16 +132,24 @@ class TestModelComponent(TestCase):
 
     def test_external_references(self) -> None:
         c1 = Component(name='test-component')
+        properties = [
+            Property(name='property_1', value='value_1'),
+            Property(name='property_2', value='value_2')
+        ]
         c1.external_references.add(ExternalReference(
             type=ExternalReferenceType.OTHER,
             url=XsUri('https://cyclonedx.org'),
-            comment='No comment'
+            comment='No comment',
+            properties=properties
         ))
         self.assertEqual(c1.name, 'test-component')
         self.assertIsNone(c1.version)
         self.assertEqual(c1.type, ComponentType.LIBRARY)
         self.assertEqual(len(c1.external_references), 1)
         self.assertEqual(len(c1.hashes), 0)
+        self.assertIsNotNone(c1.external_references[0].properties)
+        self.assertIn(properties[0], c1.external_references[0].properties)
+        self.assertIn(properties[1], c1.external_references[0].properties)
 
         c2 = Component(name='test2-component')
         self.assertEqual(c2.name, 'test2-component')
@@ -174,18 +171,20 @@ class TestModelComponent(TestCase):
         c1.external_references.add(ExternalReference(
             type=ExternalReferenceType.OTHER,
             url=XsUri('https://cyclonedx.org'),
-            comment='No comment'
+            comment='No comment',
+            properties=[Property(name='property_1', value='value_1')]
         ))
         c2 = Component(name='test-component')
         c2.external_references.add(ExternalReference(
             type=ExternalReferenceType.OTHER,
             url=XsUri('https://cyclonedx.org'),
-            comment='No comment'
+            comment='No comment',
+            properties=[Property(name='property_1', value='value_1')]
         ))
         self.assertEqual(c1, c2)
 
     def test_component_equal_2(self) -> None:
-        props: List[Property] = (
+        props: list[Property] = (
             Property(name='prop1', value='val1'),
             Property(name='prop2', value='val2'),
         )
@@ -286,30 +285,6 @@ class TestModelComponent(TestCase):
         self.assertEqual(2, len(comp_b.get_all_nested_components(include_self=False)))
 
 
-class TestModelComponentEvidence(TestCase):
-
-    def test_no_params(self) -> None:
-        ComponentEvidence()  # Does not raise `NoPropertiesProvidedException`
-
-    def test_same_1(self) -> None:
-        ce_1 = ComponentEvidence(copyright=[Copyright(text='Commercial')])
-        ce_2 = ComponentEvidence(copyright=[Copyright(text='Commercial')])
-        self.assertEqual(hash(ce_1), hash(ce_2))
-        self.assertTrue(ce_1 == ce_2)
-
-    def test_same_2(self) -> None:
-        ce_1 = ComponentEvidence(copyright=[Copyright(text='Commercial'), Copyright(text='Commercial 2')])
-        ce_2 = ComponentEvidence(copyright=[Copyright(text='Commercial 2'), Copyright(text='Commercial')])
-        self.assertEqual(hash(ce_1), hash(ce_2))
-        self.assertTrue(ce_1 == ce_2)
-
-    def test_not_same_1(self) -> None:
-        ce_1 = ComponentEvidence(copyright=[Copyright(text='Commercial')])
-        ce_2 = ComponentEvidence(copyright=[Copyright(text='Commercial 2')])
-        self.assertNotEqual(hash(ce_1), hash(ce_2))
-        self.assertFalse(ce_1 == ce_2)
-
-
 class TestModelDiff(TestCase):
 
     def test_no_params(self) -> None:
@@ -454,6 +429,17 @@ class TestModelPedigree(TestCase):
         self.assertNotEqual(hash(p1), hash(p2), 'hash')
         self.assertFalse(p1 == p2, 'equal')
 
+    def test_pedigree_sorting(self) -> None:
+        """Test that Pedigree instances can be sorted without triggering TypeError"""
+        p1 = Pedigree(notes='Note A')
+        p2 = Pedigree(notes='Note B')
+        p3 = Pedigree(notes='Note C')
+
+        # This should not raise TypeError: '<' not supported between instances
+        pedigree_list = [p3, p1, p2]
+        sorted_pedigree = sorted(pedigree_list)
+        self.assertEqual(len(sorted_pedigree), 3)
+
 
 class TestModelSwid(TestCase):
 
@@ -477,3 +463,14 @@ class TestModelSwid(TestCase):
         self.assertNotEqual(id(sw_1), id(sw_2), 'id')
         self.assertNotEqual(hash(sw_1), hash(sw_2), 'hash')
         self.assertFalse(sw_1 == sw_2, 'equal')
+
+    def test_swid_sorting(self) -> None:
+        """Test that Swid instances can be sorted without triggering TypeError"""
+        sw_1 = get_swid_1()
+        sw_2 = get_swid_2()
+        sw_3 = get_swid_1()
+
+        # This should not raise TypeError: '<' not supported between instances
+        swid_list = [sw_2, sw_1, sw_3]
+        sorted_swid = sorted(swid_list)
+        self.assertEqual(len(sorted_swid), 3)
